Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(551)

Unified Diff: pkg/unittest/lib/src/interfaces.dart

Issue 16408019: Improved error messages from unittest. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/unittest/lib/src/interfaces.dart
===================================================================
--- pkg/unittest/lib/src/interfaces.dart (revision 24002)
+++ pkg/unittest/lib/src/interfaces.dart (working copy)
@@ -16,7 +16,7 @@
* error formatter with another.
*/
typedef String ErrorFormatter(actual, Matcher matcher, String reason,
- MatchState matchState, bool verbose);
+ Map matchState, bool verbose);
/**
* Matchers build up their error messages by appending to
@@ -58,7 +58,7 @@
* and may be used to add details about the mismatch that are too
* costly to determine in [describeMismatch].
*/
- bool matches(item, MatchState matchState);
+ bool matches(item, Map matchState);
/** This builds a textual description of the matcher. */
Description describe(Description description);
@@ -66,7 +66,7 @@
/**
* This builds a textual description of a specific mismatch. [item]
* is the value that was tested by [matches]; [matchState] is
* the [MatchState] that was passed to and supplemented by [matches]
* with additional information about the mismact, and [mismatchDescription]
* is the [Description] that is being built to decribe the mismatch.
* A few matchers make use of the [verbose] flag to provide detailed
@@ -74,7 +74,7 @@
* diagnosing failures, such as stack traces.
*/
Description describeMismatch(item, Description mismatchDescription,
- MatchState matchState, bool verbose);
+ Map matchState, bool verbose);
}
/**
@@ -96,6 +96,6 @@
* an [ErrorFormatter]) and then call [fail] with this message.
*/
void failMatch(actual, Matcher matcher, String reason,
- MatchState matchState, bool verbose);
+ Map matchState, bool verbose);
}

Powered by Google App Engine
@@ -66,7 +66,7 @@
* This builds a textual description of a specific mismatch. [item]
* is the value that was tested by [matches]; [matchState] is
- * the [MatchState] that was passed to and supplemented by [matches]
+ * the [Map] that was passed to and supplemented by [matches]
* with additional information about the mismact, and [mismatchDescription]
* is the [Description] that is being built to decribe the mismatch.
This is Rietveld 408576698